//                              -*- Mode: C++ -*- 
// 
// uC++ Version 5.3.0, Copyright (C) Russell Mok 1997
// 
// uKernelEvent.h -- 
// 
// Author           : Russell Mok
// Created On       : Mon Jun 30 22:14:03 1997
// Last Modified By : Peter A. Buhr
// Last Modified On : Fri Jun 24 14:32:34 2005
// Update Count     : 59
//
// This  library is free  software; you  can redistribute  it and/or  modify it
// under the terms of the GNU Lesser General Public License as published by the
// Free Software  Foundation; either  version 2.1 of  the License, or  (at your
// option) any later version.
// 
// This library is distributed in the  hope that it will be useful, but WITHOUT
// ANY  WARRANTY;  without even  the  implied  warranty  of MERCHANTABILITY  or
// FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License
// for more details.
// 
// You should  have received a  copy of the  GNU Lesser General  Public License
// along  with this library.
// 


#ifndef __U_KERNELEVENT_H__
#define __U_KERNELEVENT_H__


_DualEvent uKernelFailure {				// exceptional event during mutex session or synchronization session
  public:
    uKernelFailure( const char *const msg = "" );
    virtual ~uKernelFailure();
    virtual void defaultTerminate() const;
}; // uKernelFailure


#endif // __U_KERNELEVENT_H__


// Local Variables: //
// compile-command: "gmake install" //
// End: //
